%global srcname socketio

# Sphinx-generated HTML documentation is not suitable for packaging; see
# https://bugzilla.redhat.com/show_bug.cgi?id=2006555 for discussion.
#
# We can generate PDF documentation as a lesser substitute.
%bcond_without doc_pdf

Name:           python-%{srcname}
Version:        4.6.1
Release:        4%{?dist}
Summary:        Socket.IO server

License:        MIT
URL:            https://github.com/miguelgrinberg/%{name}
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros

# Documentation
%if %{with doc_pdf}
BuildRequires:  make
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3-sphinx-latex
BuildRequires:  latexmk
%endif

# Extra testing dependencies
BuildRequires:  python3dist(pytest)

%global common_description %{expand:
Socket.IO is a transport protocol that enables real-time bidirectional
event-based communication between clients (typically, though not always, web
browsers) and a server. The official implementations of the client and server
components are written in JavaScript. This package provides Python
implementations of both, each with standard and asyncio variants.}

%description %{common_description}


%generate_buildrequires
%pyproject_buildrequires -x client,asyncio_client


%package -n     python3-%{srcname}
Summary:        %{summary}

%description -n python3-%{srcname} %{common_description}


%pyproject_extras_subpkg -n python3-%{srcname} client asyncio_client


%package        doc
Summary:        Documentation for %{name}

%description    doc %{common_description}


%prep
%autosetup

# Find executable files without shebang lines, and fix their permissions. Note
# that in the latest upstream, these have all been fixed except setup.py, for
# which there is: https://github.com/miguelgrinberg/python-socketio/pull/748
find . -type f -perm /0111 |
  while read -r fn
  do
    if ! head "${fn}" | grep -E '^#!' >/dev/null
    then
      chmod -v a-x "${fn}"
    fi
  done
# Fix “/usr/bin/env python” shebangs in the examples
%py3_shebang_fix examples


%build
%pyproject_wheel
%if %{with doc_pdf}
PYTHONPATH="${PWD}" %make_build -C docs latex SPHINXOPTS='%{?_smp_mflags}'
%make_build -C docs/_build/latex
%endif


%install
%pyproject_install
%pyproject_save_files %{srcname}


%check
# Test{AsyncServer,Client,Server}.test_logger are failing with:
#   AssertionError: 30 != 40
# This should be looked into more closely if it is not fixed in a later release.
%pytest -k 'not test_logger'


%files -n python3-%{srcname} -f %{pyproject_files}
%license LICENSE


%files doc
%license LICENSE
%doc CHANGES.md
%doc README.rst
%if %{with doc_pdf}
%doc docs/_build/latex/python-socketio.pdf
%endif
%doc examples


%changelog
* Fri Oct 01 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 4.6.1-4
- Fix PYTHONPATH (again) when building documentation

* Fri Oct 01 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 4.6.1-3
- Fix PYTHONPATH when building documentation

* Wed Sep 29 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 4.6.1-2
- Generate PDF instead of HTML documentation from Sphinx

* Mon Jul 05 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 4.6.1-1
- Update to 4.6.1
- Near-total spec file rewrite
- Remove obsolete practices like python_provide macro and manual Requires
- Add documentation subpackage
- Use pytest as test runner
- Fix spurious executable permissions (upstream PR#748)

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 4.6.0-3
- Rebuilt for Python 3.10

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 4.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Thu Sep 03 2020 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 4.6.0-1
- Update to 4.6.0

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.4.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 4.4.0-4
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.4.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Dec 30 2019 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 4.4.0-2
- Use expand macro for description

* Sun Dec 22 2019 Mukundan Ragavan <nonamedotc@gmail.com> - 4.4.0-1
- Initial package.
